Class: NilClass
- Inherits:
-
Object
- Object
- NilClass
- Defined in:
- lib/humanize_boolean.rb
Instance Method Summary collapse
-
#humanize ⇒ Object
The humanize method to return the string “Nothing” or a translation of that for the key locale.boolean.nil.
Instance Method Details
#humanize ⇒ Object
The humanize method to return the string “Nothing” or a translation of that for the key locale.boolean.nil
nil.humanize # => "Nothing"
34 35 36 |
# File 'lib/humanize_boolean.rb', line 34 def humanize I18n.t "boolean.nil", :default => "Nothing" end |